| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (garetxe@gmail.com) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.GtkSource.Objects.MarkAttributes
Contents
Description
- newtype MarkAttributes = MarkAttributes (ManagedPtr MarkAttributes)
- class GObject o => IsMarkAttributes o
- toMarkAttributes :: (MonadIO m, IsMarkAttributes o) => o -> m MarkAttributes
- noMarkAttributes :: Maybe MarkAttributes
- markAttributesGetBackground :: (HasCallStack, MonadIO m, IsMarkAttributes a) => a -> m (Bool, RGBA)
- markAttributesGetGicon :: (HasCallStack, MonadIO m, IsMarkAttributes a) => a -> m Icon
- markAttributesGetIconName :: (HasCallStack, MonadIO m, IsMarkAttributes a) => a -> m Text
- markAttributesGetPixbuf :: (HasCallStack, MonadIO m, IsMarkAttributes a) => a -> m Pixbuf
- markAttributesGetStockId :: (HasCallStack, MonadIO m, IsMarkAttributes a) => a -> m Text
- markAttributesGetTooltipMarkup :: (HasCallStack, MonadIO m, IsMarkAttributes a, IsMark b) => a -> b -> m Text
- markAttributesGetTooltipText :: (HasCallStack, MonadIO m, IsMarkAttributes a, IsMark b) => a -> b -> m Text
- markAttributesNew :: (HasCallStack, MonadIO m) => m MarkAttributes
- markAttributesRenderIcon :: (HasCallStack, MonadIO m, IsMarkAttributes a, IsWidget b) => a -> b -> Int32 -> m Pixbuf
- markAttributesSetBackground :: (HasCallStack, MonadIO m, IsMarkAttributes a) => a -> RGBA -> m ()
- markAttributesSetGicon :: (HasCallStack, MonadIO m, IsMarkAttributes a, IsIcon b) => a -> b -> m ()
- markAttributesSetIconName :: (HasCallStack, MonadIO m, IsMarkAttributes a) => a -> Text -> m ()
- markAttributesSetPixbuf :: (HasCallStack, MonadIO m, IsMarkAttributes a, IsPixbuf b) => a -> b -> m ()
- markAttributesSetStockId :: (HasCallStack, MonadIO m, IsMarkAttributes a) => a -> Text -> m ()
- constructMarkAttributesBackground :: IsMarkAttributes o => RGBA -> IO (GValueConstruct o)
- getMarkAttributesBackground :: (MonadIO m, IsMarkAttributes o) => o -> m (Maybe RGBA)
- setMarkAttributesBackground :: (MonadIO m, IsMarkAttributes o) => o -> RGBA -> m ()
- constructMarkAttributesGicon :: (IsMarkAttributes o, IsIcon a) => a -> IO (GValueConstruct o)
- getMarkAttributesGicon :: (MonadIO m, IsMarkAttributes o) => o -> m Icon
- setMarkAttributesGicon :: (MonadIO m, IsMarkAttributes o, IsIcon a) => o -> a -> m ()
- constructMarkAttributesIconName :: IsMarkAttributes o => Text -> IO (GValueConstruct o)
- getMarkAttributesIconName :: (MonadIO m, IsMarkAttributes o) => o -> m Text
- setMarkAttributesIconName :: (MonadIO m, IsMarkAttributes o) => o -> Text -> m ()
- constructMarkAttributesPixbuf :: (IsMarkAttributes o, IsPixbuf a) => a -> IO (GValueConstruct o)
- getMarkAttributesPixbuf :: (MonadIO m, IsMarkAttributes o) => o -> m Pixbuf
- setMarkAttributesPixbuf :: (MonadIO m, IsMarkAttributes o, IsPixbuf a) => o -> a -> m ()
- constructMarkAttributesStockId :: IsMarkAttributes o => Text -> IO (GValueConstruct o)
- getMarkAttributesStockId :: (MonadIO m, IsMarkAttributes o) => o -> m Text
- setMarkAttributesStockId :: (MonadIO m, IsMarkAttributes o) => o -> Text -> m ()
- type C_MarkAttributesQueryTooltipMarkupCallback = Ptr () -> Ptr Mark -> Ptr () -> IO CString
- type MarkAttributesQueryTooltipMarkupCallback = Mark -> IO Text
- afterMarkAttributesQueryTooltipMarkup :: (IsMarkAttributes a, MonadIO m) => a -> MarkAttributesQueryTooltipMarkupCallback -> m SignalHandlerId
- genClosure_MarkAttributesQueryTooltipMarkup :: MarkAttributesQueryTooltipMarkupCallback -> IO Closure
- mk_MarkAttributesQueryTooltipMarkupCallback :: C_MarkAttributesQueryTooltipMarkupCallback -> IO (FunPtr C_MarkAttributesQueryTooltipMarkupCallback)
- noMarkAttributesQueryTooltipMarkupCallback :: Maybe MarkAttributesQueryTooltipMarkupCallback
- onMarkAttributesQueryTooltipMarkup :: (IsMarkAttributes a, MonadIO m) => a -> MarkAttributesQueryTooltipMarkupCallback -> m SignalHandlerId
- wrap_MarkAttributesQueryTooltipMarkupCallback :: MarkAttributesQueryTooltipMarkupCallback -> Ptr () -> Ptr Mark -> Ptr () -> IO CString
- type C_MarkAttributesQueryTooltipTextCallback = Ptr () -> Ptr Mark -> Ptr () -> IO CString
- type MarkAttributesQueryTooltipTextCallback = Mark -> IO Text
- afterMarkAttributesQueryTooltipText :: (IsMarkAttributes a, MonadIO m) => a -> MarkAttributesQueryTooltipTextCallback -> m SignalHandlerId
- genClosure_MarkAttributesQueryTooltipText :: MarkAttributesQueryTooltipTextCallback -> IO Closure
- mk_MarkAttributesQueryTooltipTextCallback :: C_MarkAttributesQueryTooltipTextCallback -> IO (FunPtr C_MarkAttributesQueryTooltipTextCallback)
- noMarkAttributesQueryTooltipTextCallback :: Maybe MarkAttributesQueryTooltipTextCallback
- onMarkAttributesQueryTooltipText :: (IsMarkAttributes a, MonadIO m) => a -> MarkAttributesQueryTooltipTextCallback -> m SignalHandlerId
- wrap_MarkAttributesQueryTooltipTextCallback :: MarkAttributesQueryTooltipTextCallback -> Ptr () -> Ptr Mark -> Ptr () -> IO CString
Exported types
newtype MarkAttributes Source #
Constructors
| MarkAttributes (ManagedPtr MarkAttributes) |
class GObject o => IsMarkAttributes o Source #
Instances
toMarkAttributes :: (MonadIO m, IsMarkAttributes o) => o -> m MarkAttributes Source #
Methods
getBackground
markAttributesGetBackground Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a) | |
| => a |
|
| -> m (Bool, RGBA) | Returns: whether background color for |
Stores background color in background.
getGicon
markAttributesGetGicon Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a) | |
| => a |
|
| -> m Icon | Returns: An icon. The icon belongs to |
getIconName
markAttributesGetIconName Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a) | |
| => a |
|
| -> m Text | Returns: An icon name. The string belongs to |
Gets a name of an icon to be used as a base for rendered icon. Note that the
icon name can be Nothing if it wasn't set earlier.
getPixbuf
markAttributesGetPixbuf Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a) | |
| => a |
|
| -> m Pixbuf | Returns: A pixbuf. The pixbuf belongs to |
getStockId
markAttributesGetStockId Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a) | |
| => a |
|
| -> m Text | Returns: Stock id. Returned string is owned by |
Deprecated: (Since version 3.10)Don't use this function.
Gets a stock id of an icon used by this attributes. Note that the stock id can
be Nothing if it wasn't set earlier.
getTooltipMarkup
markAttributesGetTooltipMarkup Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a, IsMark b) | |
| => a |
|
| -> b |
|
| -> m Text | Returns: A tooltip. The returned string should be freed by
using |
Queries for a tooltip by emitting
a MarkAttributes::query-tooltip-markup signal. The tooltip may contain
a markup.
getTooltipText
markAttributesGetTooltipText Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a, IsMark b) | |
| => a |
|
| -> b |
|
| -> m Text | Returns: A tooltip. The returned string should be freed by
using |
Queries for a tooltip by emitting
a MarkAttributes::query-tooltip-text signal. The tooltip is a plain
text.
new
Arguments
| :: (HasCallStack, MonadIO m) | |
| => m MarkAttributes | Returns: a new source mark attributes. |
Creates a new source mark attributes.
renderIcon
markAttributesRenderIcon Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a, IsWidget b) | |
| => a |
|
| -> b |
|
| -> Int32 |
|
| -> m Pixbuf | Returns: A rendered pixbuf. The pixbuf belongs to |
Renders an icon of given size. The base of the icon is set by the last call
to one of: markAttributesSetPixbuf,
markAttributesSetGicon,
markAttributesSetIconName or
markAttributesSetStockId. size cannot be lower than 1.
setBackground
markAttributesSetBackground Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a) | |
| => a |
|
| -> RGBA |
|
| -> m () |
Sets background color to the one given in background.
setGicon
markAttributesSetGicon Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a, IsIcon b) | |
| => a |
|
| -> b |
|
| -> m () |
Sets an icon to be used as a base for rendered icon.
setIconName
markAttributesSetIconName Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a) | |
| => a |
|
| -> Text |
|
| -> m () |
Sets a name of an icon to be used as a base for rendered icon.
setPixbuf
markAttributesSetPixbuf Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a, IsPixbuf b) | |
| => a |
|
| -> b |
|
| -> m () |
Sets a pixbuf to be used as a base for rendered icon.
setStockId
markAttributesSetStockId Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMarkAttributes a) | |
| => a |
|
| -> Text |
|
| -> m () |
Deprecated: (Since version 3.10)Don't use this function.
Sets stock id to be used as a base for rendered icon.
Properties
background
constructMarkAttributesBackground :: IsMarkAttributes o => RGBA -> IO (GValueConstruct o) Source #
getMarkAttributesBackground :: (MonadIO m, IsMarkAttributes o) => o -> m (Maybe RGBA) Source #
setMarkAttributesBackground :: (MonadIO m, IsMarkAttributes o) => o -> RGBA -> m () Source #
gicon
constructMarkAttributesGicon :: (IsMarkAttributes o, IsIcon a) => a -> IO (GValueConstruct o) Source #
getMarkAttributesGicon :: (MonadIO m, IsMarkAttributes o) => o -> m Icon Source #
setMarkAttributesGicon :: (MonadIO m, IsMarkAttributes o, IsIcon a) => o -> a -> m () Source #
iconName
constructMarkAttributesIconName :: IsMarkAttributes o => Text -> IO (GValueConstruct o) Source #
getMarkAttributesIconName :: (MonadIO m, IsMarkAttributes o) => o -> m Text Source #
setMarkAttributesIconName :: (MonadIO m, IsMarkAttributes o) => o -> Text -> m () Source #
pixbuf
constructMarkAttributesPixbuf :: (IsMarkAttributes o, IsPixbuf a) => a -> IO (GValueConstruct o) Source #
getMarkAttributesPixbuf :: (MonadIO m, IsMarkAttributes o) => o -> m Pixbuf Source #
setMarkAttributesPixbuf :: (MonadIO m, IsMarkAttributes o, IsPixbuf a) => o -> a -> m () Source #
stockId
constructMarkAttributesStockId :: IsMarkAttributes o => Text -> IO (GValueConstruct o) Source #
getMarkAttributesStockId :: (MonadIO m, IsMarkAttributes o) => o -> m Text Source #
setMarkAttributesStockId :: (MonadIO m, IsMarkAttributes o) => o -> Text -> m () Source #
Signals
queryTooltipMarkup
type C_MarkAttributesQueryTooltipMarkupCallback = Ptr () -> Ptr Mark -> Ptr () -> IO CString Source #
afterMarkAttributesQueryTooltipMarkup :: (IsMarkAttributes a, MonadIO m) => a -> MarkAttributesQueryTooltipMarkupCallback -> m SignalHandlerId Source #
genClosure_MarkAttributesQueryTooltipMarkup :: MarkAttributesQueryTooltipMarkupCallback -> IO Closure Source #
mk_MarkAttributesQueryTooltipMarkupCallback :: C_MarkAttributesQueryTooltipMarkupCallback -> IO (FunPtr C_MarkAttributesQueryTooltipMarkupCallback) Source #
noMarkAttributesQueryTooltipMarkupCallback :: Maybe MarkAttributesQueryTooltipMarkupCallback Source #
onMarkAttributesQueryTooltipMarkup :: (IsMarkAttributes a, MonadIO m) => a -> MarkAttributesQueryTooltipMarkupCallback -> m SignalHandlerId Source #
wrap_MarkAttributesQueryTooltipMarkupCallback :: MarkAttributesQueryTooltipMarkupCallback -> Ptr () -> Ptr Mark -> Ptr () -> IO CString Source #
queryTooltipText
afterMarkAttributesQueryTooltipText :: (IsMarkAttributes a, MonadIO m) => a -> MarkAttributesQueryTooltipTextCallback -> m SignalHandlerId Source #
genClosure_MarkAttributesQueryTooltipText :: MarkAttributesQueryTooltipTextCallback -> IO Closure Source #
mk_MarkAttributesQueryTooltipTextCallback :: C_MarkAttributesQueryTooltipTextCallback -> IO (FunPtr C_MarkAttributesQueryTooltipTextCallback) Source #
onMarkAttributesQueryTooltipText :: (IsMarkAttributes a, MonadIO m) => a -> MarkAttributesQueryTooltipTextCallback -> m SignalHandlerId Source #
wrap_MarkAttributesQueryTooltipTextCallback :: MarkAttributesQueryTooltipTextCallback -> Ptr () -> Ptr Mark -> Ptr () -> IO CString Source #