| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (garetxe@gmail.com) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.GtkSource.Objects.SearchSettings
Contents
Description
- newtype SearchSettings = SearchSettings (ManagedPtr SearchSettings)
- class GObject o => IsSearchSettings o
- toSearchSettings :: (MonadIO m, IsSearchSettings o) => o -> m SearchSettings
- noSearchSettings :: Maybe SearchSettings
- searchSettingsGetAtWordBoundaries :: (HasCallStack, MonadIO m, IsSearchSettings a) => a -> m Bool
- searchSettingsGetCaseSensitive :: (HasCallStack, MonadIO m, IsSearchSettings a) => a -> m Bool
- searchSettingsGetRegexEnabled :: (HasCallStack, MonadIO m, IsSearchSettings a) => a -> m Bool
- searchSettingsGetSearchText :: (HasCallStack, MonadIO m, IsSearchSettings a) => a -> m (Maybe Text)
- searchSettingsGetWrapAround :: (HasCallStack, MonadIO m, IsSearchSettings a) => a -> m Bool
- searchSettingsNew :: (HasCallStack, MonadIO m) => m SearchSettings
- searchSettingsSetAtWordBoundaries :: (HasCallStack, MonadIO m, IsSearchSettings a) => a -> Bool -> m ()
- searchSettingsSetCaseSensitive :: (HasCallStack, MonadIO m, IsSearchSettings a) => a -> Bool -> m ()
- searchSettingsSetRegexEnabled :: (HasCallStack, MonadIO m, IsSearchSettings a) => a -> Bool -> m ()
- searchSettingsSetSearchText :: (HasCallStack, MonadIO m, IsSearchSettings a) => a -> Maybe Text -> m ()
- searchSettingsSetWrapAround :: (HasCallStack, MonadIO m, IsSearchSettings a) => a -> Bool -> m ()
- constructSearchSettingsAtWordBoundaries :: IsSearchSettings o => Bool -> IO (GValueConstruct o)
- getSearchSettingsAtWordBoundaries :: (MonadIO m, IsSearchSettings o) => o -> m Bool
- setSearchSettingsAtWordBoundaries :: (MonadIO m, IsSearchSettings o) => o -> Bool -> m ()
- constructSearchSettingsCaseSensitive :: IsSearchSettings o => Bool -> IO (GValueConstruct o)
- getSearchSettingsCaseSensitive :: (MonadIO m, IsSearchSettings o) => o -> m Bool
- setSearchSettingsCaseSensitive :: (MonadIO m, IsSearchSettings o) => o -> Bool -> m ()
- constructSearchSettingsRegexEnabled :: IsSearchSettings o => Bool -> IO (GValueConstruct o)
- getSearchSettingsRegexEnabled :: (MonadIO m, IsSearchSettings o) => o -> m Bool
- setSearchSettingsRegexEnabled :: (MonadIO m, IsSearchSettings o) => o -> Bool -> m ()
- clearSearchSettingsSearchText :: (MonadIO m, IsSearchSettings o) => o -> m ()
- constructSearchSettingsSearchText :: IsSearchSettings o => Text -> IO (GValueConstruct o)
- getSearchSettingsSearchText :: (MonadIO m, IsSearchSettings o) => o -> m (Maybe Text)
- setSearchSettingsSearchText :: (MonadIO m, IsSearchSettings o) => o -> Text -> m ()
- constructSearchSettingsWrapAround :: IsSearchSettings o => Bool -> IO (GValueConstruct o)
- getSearchSettingsWrapAround :: (MonadIO m, IsSearchSettings o) => o -> m Bool
- setSearchSettingsWrapAround :: (MonadIO m, IsSearchSettings o) => o -> Bool -> m ()
Exported types
newtype SearchSettings Source #
Constructors
| SearchSettings (ManagedPtr SearchSettings) |
class GObject o => IsSearchSettings o Source #
Instances
toSearchSettings :: (MonadIO m, IsSearchSettings o) => o -> m SearchSettings Source #
Methods
getAtWordBoundaries
searchSettingsGetAtWordBoundaries Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSearchSettings a) | |
| => a |
|
| -> m Bool | Returns: whether to search at word boundaries. |
No description available in the introspection data.
Since: 3.10
getCaseSensitive
searchSettingsGetCaseSensitive Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSearchSettings a) | |
| => a |
|
| -> m Bool | Returns: whether the search is case sensitive. |
No description available in the introspection data.
Since: 3.10
getRegexEnabled
searchSettingsGetRegexEnabled Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSearchSettings a) | |
| => a |
|
| -> m Bool | Returns: whether to search by regular expressions. |
No description available in the introspection data.
Since: 3.10
getSearchText
searchSettingsGetSearchText Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSearchSettings a) | |
| => a |
|
| -> m (Maybe Text) | Returns: the text to search, or |
Gets the text to search. The return value must not be freed.
You may be interested to call utilsEscapeSearchText after
this function.
Since: 3.10
getWrapAround
searchSettingsGetWrapAround Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSearchSettings a) | |
| => a |
|
| -> m Bool | Returns: whether to wrap around the search. |
No description available in the introspection data.
Since: 3.10
new
Arguments
| :: (HasCallStack, MonadIO m) | |
| => m SearchSettings | Returns: a new search settings object. |
Creates a new search settings object.
Since: 3.10
setAtWordBoundaries
searchSettingsSetAtWordBoundaries Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSearchSettings a) | |
| => a |
|
| -> Bool |
|
| -> m () |
Change whether the search is done at word boundaries. If atWordBoundaries
is True, a search match must start and end a word. The match can span
multiple words. See also textIterStartsWord and
textIterEndsWord.
Since: 3.10
setCaseSensitive
searchSettingsSetCaseSensitive Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSearchSettings a) | |
| => a |
|
| -> Bool |
|
| -> m () |
Enables or disables the case sensitivity for the search.
Since: 3.10
setRegexEnabled
searchSettingsSetRegexEnabled Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSearchSettings a) | |
| => a |
|
| -> Bool |
|
| -> m () |
Enables or disables whether to search by regular expressions.
If enabled, the SearchSettings:search-text property contains the
pattern of the regular expression.
SearchContext uses Regex when regex search is enabled. See the
Regular expression syntax
page in the GLib reference manual.
Since: 3.10
setSearchText
searchSettingsSetSearchText Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSearchSettings a) | |
| => a |
|
| -> Maybe Text |
|
| -> m () |
Sets the text to search. If text is Nothing or is empty, the search will be
disabled. A copy of text will be made, so you can safely free text after
a call to this function.
You may be interested to call utilsUnescapeSearchText before
this function.
Since: 3.10
setWrapAround
searchSettingsSetWrapAround Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSearchSettings a) | |
| => a |
|
| -> Bool |
|
| -> m () |
Enables or disables the wrap around search. If wrapAround is True, the
forward search continues at the beginning of the buffer if no search
occurrences are found. Similarly, the backward search continues to search at
the end of the buffer.
Since: 3.10
Properties
atWordBoundaries
constructSearchSettingsAtWordBoundaries :: IsSearchSettings o => Bool -> IO (GValueConstruct o) Source #
getSearchSettingsAtWordBoundaries :: (MonadIO m, IsSearchSettings o) => o -> m Bool Source #
setSearchSettingsAtWordBoundaries :: (MonadIO m, IsSearchSettings o) => o -> Bool -> m () Source #
caseSensitive
constructSearchSettingsCaseSensitive :: IsSearchSettings o => Bool -> IO (GValueConstruct o) Source #
getSearchSettingsCaseSensitive :: (MonadIO m, IsSearchSettings o) => o -> m Bool Source #
setSearchSettingsCaseSensitive :: (MonadIO m, IsSearchSettings o) => o -> Bool -> m () Source #
regexEnabled
constructSearchSettingsRegexEnabled :: IsSearchSettings o => Bool -> IO (GValueConstruct o) Source #
getSearchSettingsRegexEnabled :: (MonadIO m, IsSearchSettings o) => o -> m Bool Source #
setSearchSettingsRegexEnabled :: (MonadIO m, IsSearchSettings o) => o -> Bool -> m () Source #
searchText
clearSearchSettingsSearchText :: (MonadIO m, IsSearchSettings o) => o -> m () Source #
constructSearchSettingsSearchText :: IsSearchSettings o => Text -> IO (GValueConstruct o) Source #
getSearchSettingsSearchText :: (MonadIO m, IsSearchSettings o) => o -> m (Maybe Text) Source #
setSearchSettingsSearchText :: (MonadIO m, IsSearchSettings o) => o -> Text -> m () Source #
wrapAround
constructSearchSettingsWrapAround :: IsSearchSettings o => Bool -> IO (GValueConstruct o) Source #
getSearchSettingsWrapAround :: (MonadIO m, IsSearchSettings o) => o -> m Bool Source #
setSearchSettingsWrapAround :: (MonadIO m, IsSearchSettings o) => o -> Bool -> m () Source #