| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (garetxe@gmail.com) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.GtkSource.Objects.SpaceDrawer
Contents
Description
- newtype SpaceDrawer = SpaceDrawer (ManagedPtr SpaceDrawer)
- class GObject o => IsSpaceDrawer o
- toSpaceDrawer :: (MonadIO m, IsSpaceDrawer o) => o -> m SpaceDrawer
- noSpaceDrawer :: Maybe SpaceDrawer
- spaceDrawerBindMatrixSetting :: (HasCallStack, MonadIO m, IsSpaceDrawer a, IsSettings b) => a -> b -> Text -> [SettingsBindFlags] -> m ()
- spaceDrawerGetEnableMatrix :: (HasCallStack, MonadIO m, IsSpaceDrawer a) => a -> m Bool
- spaceDrawerGetMatrix :: (HasCallStack, MonadIO m, IsSpaceDrawer a) => a -> m GVariant
- spaceDrawerGetTypesForLocations :: (HasCallStack, MonadIO m, IsSpaceDrawer a) => a -> [SpaceLocationFlags] -> m [SpaceTypeFlags]
- spaceDrawerNew :: (HasCallStack, MonadIO m) => m SpaceDrawer
- spaceDrawerSetEnableMatrix :: (HasCallStack, MonadIO m, IsSpaceDrawer a) => a -> Bool -> m ()
- spaceDrawerSetMatrix :: (HasCallStack, MonadIO m, IsSpaceDrawer a) => a -> Maybe GVariant -> m ()
- spaceDrawerSetTypesForLocations :: (HasCallStack, MonadIO m, IsSpaceDrawer a) => a -> [SpaceLocationFlags] -> [SpaceTypeFlags] -> m ()
- constructSpaceDrawerEnableMatrix :: IsSpaceDrawer o => Bool -> IO (GValueConstruct o)
- getSpaceDrawerEnableMatrix :: (MonadIO m, IsSpaceDrawer o) => o -> m Bool
- setSpaceDrawerEnableMatrix :: (MonadIO m, IsSpaceDrawer o) => o -> Bool -> m ()
- clearSpaceDrawerMatrix :: (MonadIO m, IsSpaceDrawer o) => o -> m ()
- constructSpaceDrawerMatrix :: IsSpaceDrawer o => GVariant -> IO (GValueConstruct o)
- getSpaceDrawerMatrix :: (MonadIO m, IsSpaceDrawer o) => o -> m (Maybe GVariant)
- setSpaceDrawerMatrix :: (MonadIO m, IsSpaceDrawer o) => o -> GVariant -> m ()
Exported types
class GObject o => IsSpaceDrawer o Source #
Instances
toSpaceDrawer :: (MonadIO m, IsSpaceDrawer o) => o -> m SpaceDrawer Source #
Methods
bindMatrixSetting
spaceDrawerBindMatrixSetting Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSpaceDrawer a, IsSettings b) | |
| => a |
|
| -> b |
|
| -> Text |
|
| -> [SettingsBindFlags] |
|
| -> m () |
Binds the SpaceDrawer:matrix property to a Settings key.
The Settings key must be of the same type as the
SpaceDrawer:matrix property, that is, "au".
The settingsBind function cannot be used, because the default GIO
mapping functions don't support GVariant properties (maybe it will be
supported by a future GIO version, in which case this function can be
deprecated).
Since: 3.24
getEnableMatrix
spaceDrawerGetEnableMatrix Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSpaceDrawer a) | |
| => a |
|
| -> m Bool | Returns: whether the |
No description available in the introspection data.
Since: 3.24
getMatrix
Arguments
| :: (HasCallStack, MonadIO m, IsSpaceDrawer a) | |
| => a |
|
| -> m GVariant | Returns: the |
Gets the value of the SpaceDrawer:matrix property, as a GVariant.
An empty array can be returned in case the matrix is a zero matrix.
The spaceDrawerGetTypesForLocations function may be more
convenient to use.
Since: 3.24
getTypesForLocations
spaceDrawerGetTypesForLocations Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSpaceDrawer a) | |
| => a |
|
| -> [SpaceLocationFlags] |
|
| -> m [SpaceTypeFlags] | Returns: a combination of |
If only one location is specified, this function returns what kind of
white spaces are drawn at that location. The value is retrieved from the
SpaceDrawer:matrix property.
If several locations are specified, this function returns the logical AND for
those locations. Which means that if a certain kind of white space is present
in the return value, then that kind of white space is drawn at all the
specified locations.
Since: 3.24
new
Arguments
| :: (HasCallStack, MonadIO m) | |
| => m SpaceDrawer | Returns: a new |
Creates a new SpaceDrawer object. Useful for storing space drawing
settings independently of a View.
Since: 3.24
setEnableMatrix
spaceDrawerSetEnableMatrix Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSpaceDrawer a) | |
| => a |
|
| -> Bool |
|
| -> m () |
Sets whether the SpaceDrawer:matrix property is enabled.
Since: 3.24
setMatrix
Arguments
| :: (HasCallStack, MonadIO m, IsSpaceDrawer a) | |
| => a |
|
| -> Maybe GVariant |
|
| -> m () |
Sets a new value to the SpaceDrawer:matrix property, as a
GVariant. If matrix is Nothing, then an empty array is set.
If matrix is floating, it is consumed.
The spaceDrawerSetTypesForLocations function may be more
convenient to use.
Since: 3.24
setTypesForLocations
spaceDrawerSetTypesForLocations Source #
Arguments
| :: (HasCallStack, MonadIO m, IsSpaceDrawer a) | |
| => a |
|
| -> [SpaceLocationFlags] |
|
| -> [SpaceTypeFlags] |
|
| -> m () |
Modifies the SpaceDrawer:matrix property at the specified
locations.
Since: 3.24
Properties
enableMatrix
constructSpaceDrawerEnableMatrix :: IsSpaceDrawer o => Bool -> IO (GValueConstruct o) Source #
getSpaceDrawerEnableMatrix :: (MonadIO m, IsSpaceDrawer o) => o -> m Bool Source #
setSpaceDrawerEnableMatrix :: (MonadIO m, IsSpaceDrawer o) => o -> Bool -> m () Source #
matrix
clearSpaceDrawerMatrix :: (MonadIO m, IsSpaceDrawer o) => o -> m () Source #
constructSpaceDrawerMatrix :: IsSpaceDrawer o => GVariant -> IO (GValueConstruct o) Source #
getSpaceDrawerMatrix :: (MonadIO m, IsSpaceDrawer o) => o -> m (Maybe GVariant) Source #
setSpaceDrawerMatrix :: (MonadIO m, IsSpaceDrawer o) => o -> GVariant -> m () Source #